================
django-email-log
================

.. image:: https://img.shields.io/pypi/v/django-email-log.svg
   :target: https://pypi.org/project/django-email-log/
   :alt: PyPI
.. image:: https://img.shields.io/pypi/pyversions/django-email-log
   :target: https://pypi.org/project/django-email-log
   :alt: Python Version
.. image:: https://img.shields.io/pypi/djversions/django-email-log
   :target: https://pypi.org/project/django-email-log
   :alt: Django Version
.. image:: https://img.shields.io/readthedocs/django-email-log/latest.svg?label=Read%20the%20Docs
   :target: https://django-email-log.readthedocs.io/
   :alt: Read the documentation at https://django-email-log.readthedocs.io/
.. image:: https://github.com/treyhunner/django-email-log/workflows/Tests/badge.svg
   :target: https://github.com/treyhunner/django-email-log/actions?workflow=Tests
   :alt: Tests
.. image:: https://codecov.io/gh/treyhunner/django-email-log/branch/main/graph/badge.svg
   :target: https://codecov.io/gh/treyhunner/django-email-log
   :alt: Codecov

Django email backend that logs all sent emails to a database using a Django model.

This app works with Django 2.2 to 4.1

This app requires Python 3.7+.

Getting Help
------------

Documentation for django-email-log is available at https://django-email-log.readthedocs.org/

This app is available on `PyPI`_.

Submit issues on Github: https://github.com/treyhunner/django-email-log/issues

Pull requests are welcome.  Read the CONTRIBUTING file for tips on submitting
a pull request.

.. _PyPI: https://pypi.python.org/pypi/django-email-log/


Related Projects
----------------

Thanks to the following related projects for inspiration:

- `django-mailer`_
- `django-post_office`_
- `django-celery-email`_
- Email logger mentioned in this `StackOverflow answer`_

.. _django-mailer: https://github.com/pinax/django-mailer
.. _django-celery-email: https://github.com/pmclanahan/django-celery-email
.. _django-post_office: https://github.com/ui/django-post_office
.. _stackoverflow answer: http://stackoverflow.com/a/7553759/98187
